@@ -20,15 +20,22 @@ class NewSpotOrderMessage(BaseEventMessage):
     selling: bool
 
 
-class CancelOrderMessage(BaseEventMessage):
-    order_id: str
-    exchange: str
-    market_code: str
-
-
 class UpdateOrderMessage(BaseEventMessage):
     order_id: str
     market_code: str
     exchange: str
     new_limit_price: float
     new_quantity: float
+
+class CancelOrderByIdMessage(BaseEventMessage):
+    order_id: str
+    exchange: str
+    market_code: str
+
+
+class CancelAllOrdersMessage(BaseEventMessage):
+    exchange: str
+
+class CancelOrdersByMarketMessage(BaseEventMessage):
+    exchange: str
+    market_code: str
